@@ -23,14 +23,14 @@ from circlink.link import LINKS_DIRECTORY, CircuitPythonLink
 
 _TableRowEntry: TypeAlias = Tuple[int, str, bool, pathlib.Path, pathlib.Path, bool, int]
 
-__version__ = "1.1.0"
+__version__ = "1.1.1"
 
 # Prevent running on non-POSIX systems that don't have os.fork()
 if os.name != "posix":
     print("circlink is currently only available for Linux and macOS")
     sys.exit(1)
 
-app = Typer()
+app = Typer(add_completion=False)
 
 
 def _ensure_links_folder() -> None:
